VisitorRepository class

Constructors

VisitorRepository()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

countUnreadConversations(String sessionId) Future<int>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(String sessionId, VisitorProperties payload) → dynamic

Operators

operator ==(Object other) bool
The equality operator.
inherited